@@ -1,6 +1,8 @@
 package extras
 
 import (
+	"slices"
+
 	"github.com/yuin/goldmark"
 	"github.com/yuin/goldmark/ast"
 	"github.com/yuin/goldmark/parser"
@@ -11,10 +13,10 @@ import (
 )
 
 type inlineTagDelimiterProcessor struct {
-	inlineTag
+	InlineTag
 }
 
-func newInlineTagDelimiterProcessor(tag inlineTag) parser.DelimiterProcessor {
+func newInlineTagDelimiterProcessor(tag InlineTag) parser.DelimiterProcessor {
 	return &inlineTagDelimiterProcessor{tag}
 }
 
@@ -27,15 +29,15 @@ func (p *inlineTagDelimiterProcessor) CanOpenCloser(opener, closer *parser.Delim
 }
 
 func (p *inlineTagDelimiterProcessor) OnMatch(_ int) ast.Node {
-	return newInlineTag(p.inlineTag)
+	return newInlineTag(p.InlineTag)
 }
 
 type inlineTagParser struct {
-	inlineTag
+	InlineTag
 }
 
-func newInlineTagParser(tag inlineTag) parser.InlineParser {
-	return &inlineTagParser{inlineTag: tag}
+func newInlineTagParser(tag InlineTag) parser.InlineParser {
+	return &inlineTagParser{InlineTag: tag}
 }
 
 // Trigger implements parser.InlineParser.
@@ -47,7 +49,17 @@ func (s *inlineTagParser) Trigger() []byte {
 func (s *inlineTagParser) Parse(_ ast.Node, block text.Reader, pc parser.Context) ast.Node {
 	before := block.PrecendingCharacter()
 	line, segment := block.PeekLine()
-	node := parser.ScanDelimiter(line, before, s.Number, newInlineTagDelimiterProcessor(s.inlineTag))
+
+	// Issue 30
+	modifiedLine := slices.Clone(line)
+	if s.InlineTag.TagKind == KindSuperscript && len(line) > s.Number {
+		symbols := []byte{'+', '-', '\''}
+		if slices.Contains(symbols, line[s.Number]) {
+			modifiedLine[s.Number] = 'z' // replace with any letter or number
+		}
+	}
+
+	node := parser.ScanDelimiter(modifiedLine, before, s.Number, newInlineTagDelimiterProcessor(s.InlineTag))
 	if node == nil || node.OriginalLength > 2 || before == rune(s.Char) {
 		return nil
 	}
@@ -63,8 +75,8 @@ type inlineTagHTMLRenderer struct {
 	html.Config
 }
 
-// newInlineTagHTMLRenderer returns a new NodeRenderer that renders InlineTaast.Node nodes to HTML.
-func newInlineTagHTMLRenderer(tag inlineTag, opts ...html.Option) renderer.NodeRenderer {
+// NewInlineTagHTMLRenderer returns a new NodeRenderer that renders Inline nodes to HTML.
+func NewInlineTagHTMLRenderer(tag InlineTag, opts ...html.Option) renderer.NodeRenderer {
 	r := &inlineTagHTMLRenderer{
 		htmlTag: tag.Html,
 		tagKind: tag.TagKind,
@@ -107,7 +119,7 @@ type inlineExtension struct {
 	conf Config
 }
 
-// Config confitures the extras extension.
+// Config configures the extras extension.
 type Config struct {
 	Superscript SuperscriptConfig
 	Subscript   SubscriptConfig
@@ -150,27 +162,27 @@ func New(config Config) goldmark.Extender {
 
 // Extend adds inline tags to the Markdown parser and renderer.
 func (tag *inlineExtension) Extend(md goldmark.Markdown) {
-	addTag := func(tag inlineTag) {
+	addTag := func(tag InlineTag) {
 		md.Parser().AddOptions(parser.WithInlineParsers(
 			util.Prioritized(newInlineTagParser(tag), tag.ParsePriority),
 		))
 		md.Renderer().AddOptions(renderer.WithNodeRenderers(
-			util.Prioritized(newInlineTagHTMLRenderer(tag), tag.RenderPriority),
+			util.Prioritized(NewInlineTagHTMLRenderer(tag), tag.RenderPriority),
 		))
 	}
 	if tag.conf.Superscript.Enable {
-		addTag(superscriptTag)
+		addTag(SuperscriptTag)
 	}
 	if tag.conf.Subscript.Enable {
-		addTag(subscriptTag)
+		addTag(SubscriptTag)
 	}
 	if tag.conf.Insert.Enable {
-		addTag(insertTag)
+		addTag(InsertTag)
 	}
 	if tag.conf.Mark.Enable {
-		addTag(markTag)
+		addTag(MarkTag)
 	}
 	if tag.conf.Delete.Enable {
-		addTag(deleteTag)
+		addTag(DeleteTag)
 	}
 }
